@@ -9,7 +9,7 @@ pub(crate) use self::text_writer::*;
 /// A trait to get tuple from collection items.
 /// See https://stackoverflow.com/questions/38863781/how-to-create-a-tuple-from-a-vector
 pub(crate) trait TryCollect<T> {
-    fn try_collect(&mut self) -> Option<T>;
+    fn try_collect_tuple(&mut self) -> Option<T>;
 }
 
 /// A macro to get tuple from collection items.
@@ -20,7 +20,7 @@ macro_rules! impl_try_collect_tuple {
         impl_try_collect_tuple!($($I)*);
 
         impl<$A: Iterator> TryCollect<($A::Item, $($I::Item),*)> for $A {
-            fn try_collect(&mut self) -> Option<($A::Item, $($I::Item),*)> {
+            fn try_collect_tuple(&mut self) -> Option<($A::Item, $($I::Item),*)> {
                 let r = (try_opt!(self.next()),
                          // hack: we need to use $I in the expansion
                          $({ let a: $I::Item = try_opt!(self.next()); a}),* );
