@@ -8,9 +8,9 @@ pub trait SolomonSolution<W: Write> {
     fn write_solomon(&self, writer: BufWriter<W>) -> Result<(), String>;
 }
 
-impl<W: Write> SolomonSolution<W> for Solution {
+impl<W: Write> SolomonSolution<W> for (&Solution, f64) {
     fn write_solomon(&self, writer: BufWriter<W>) -> Result<(), String> {
-        write_text_solution(writer, self).map_err(|err| err.to_string())?;
+        write_text_solution(writer, self.0, self.1).map_err(|err| err.to_string())?;
         Ok(())
     }
 }
